
Base Class Types for MatSci
============================

This module is currently an extension of the `pymatgen.core` module that adds
a few extra methods. You should consult [the pymatgen documentation](https://pymatgen.org/) for use and additional features.

In the future, we intend for this module to be a fork and refactor of `pymatgen.core`, but this milestone is hit, our developmental code will be hosted in the `_to_do` folder of this module.
